# [Bulma](http://bulma.io)

[![npm](https://img.shields.io/npm/v/bulma.svg)](https://www.npmjs.com/package/bulma)
[![npm](https://img.shields.io/npm/dm/bulma.svg)](https://www.npmjs.com/package/bulma)
[![Join the chat at https://gitter.im/jgthms/bulma](https://badges.gitter.im/jgthms/bulma.svg)](https://gitter.im/jgthms/bulma)

Bulma is a modern CSS framework based on [Flexbox](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Flexible_Box_Layout/Using_CSS_flexible_boxes).

[![Bulma: a Flexbox CSS framework](https://raw.githubusercontent.com/jgthms/bulma/master/docs/images/bulma-banner.png)](http://bulma.io)

## Quick install

Bulma is in early but active development! Try it out now:

### NPM

```sh
npm install bulma
```
**or**

### YARN

```sh
yarn add bulma
```

### Bower

```sh
bower install bulma
```

### CDN

[https://cdnjs.com/libraries/bulma](https://cdnjs.com/libraries/bulma)

Feel free to raise an issue or submit a pull request.

## CSS only

Bulma is a **CSS** framework. As such, the sole output is a single CSS file: [bulma.css](https://github.com/jgthms/bulma/blob/master/css/bulma.css)

You can either use that file, "out of the box", or download the Sass source files to customize the [variables](http://bulma.io/documentation/overview/variables/).

There is **no** JavaScript included. People generally want to use their own JS implementation (and usually already have one). Bulma can be considered "environment agnostic": it's just the style layer on top of the logic.

## Browser Support

Bulma uses [autoprefixer](https://github.com/postcss/autoprefixer) to make (most) Flexbox features compatible with earlier browser versions. According to [Can I use](http://caniuse.com/#feat=flexbox), Bulma is compatible with **recent** versions of:

* Chrome
* Edge
* Firefox
* Opera
* Safari

Internet Explorer (10+) is only partially supported.

## Documentation

The documentation resides in the [docs](docs) directory, and is built with the Ruby-based [Jekyll](https://jekyllrb.com/) tool.

Browse the [online documentation here.](http://bulma.io/documentation/overview/start/)

## Related projects

* Bulma with Attribute Modules: https://github.com/j5bot/bulma-attribute-selectors
* Bulma with Rails: https://github.com/joshuajansen/bulma-rails
* iTemplate: [http://itemplate.ga/](http://itemplate.ga/dashboard.html)
* Vue Admin powered by Bulma: https://github.com/vue-bulma/vue-admin
* Bulmaswatch — Free themes for Bulma: https://github.com/jenil/bulmaswatch
* Goldfish — Vault UI with Bulma, Golang, and Vue Admin: https://github.com/Caiyeon/goldfish
* ember-bulma - Ember addon providing a collection of UI components for Bulma https://github.com/open-tux/ember-bulma
* Bloomer — A set of React components for Bulma: https://bloomer.js.org
* Re-bulma – Bulma components build with React: https://github.com/bokuweb/re-bulma
* React-bulma – React.js components for bulma: https://github.com/kulakowka/react-bulma
* Buefy — Lightweight UI components for Vue.js based on Bulma: https://buefy.github.io
* vue-bulma-components — Bulma components for Vue.js with straightforward syntax: https://github.com/vouill/vue-bulma-components

## Copyright and license

Code copyright 2017 Jeremy Thomas. Code released under [the MIT license](https://github.com/jgthms/bulma/blob/master/LICENSE).
